@@ -1,15 +1,13 @@
-from __future__ import unicode_literals
-
+import glob
+import os
+import re
+import sys
 import warnings
-import glob, os, sys, re
-import six
-
 from importlib import import_module
 
 from .conf import conf
 
 
-
 class BaseFinder(object):
     def find(self, name):
         raise NotImplementedError()
@@ -115,8 +113,6 @@ def _get_app_template_dirs():
         for dirname in conf.JSTEMPLATE_APP_DIRNAMES:
             template_dir = os.path.join(app_dir, dirname)
             if os.path.isdir(template_dir):
-                if not six.PY3:
-                    template_dir = template_dir.decode(fs_encoding)
                 ret.append(template_dir)
     return ret
 
