@@ -1,15 +1,9 @@
-from __future__ import unicode_literals
-
 import os.path
-import six
 
-from django.test import TestCase
+from django.test import override_settings, TestCase
 from django.utils import translation
 from jstemplate.preprocessors import I18nPreprocessor
 
-from .utils import override_settings
-
-
 
 __all__ = [
     "I18nTest",
@@ -34,13 +28,9 @@ class I18nTest (TestCase):
         translation.activate("fr")
         fake_translation = translation.trans_real._active.value
 
-        # wrap the ugettext and ungettext functions so that 'XXX ' will prefix each translation
-        if six.PY3:
-            self.original_gettext = fake_translation.gettext
-            fake_translation.gettext = wrap_with_xxx(fake_translation.gettext)
-        else:
-            self.original_ugettext = fake_translation.ugettext
-            fake_translation.ugettext = wrap_with_xxx(fake_translation.ugettext)
+        # wrap the gettext and ungettext functions so that 'XXX ' will prefix each translation
+        self.original_gettext = fake_translation.gettext
+        fake_translation.gettext = wrap_with_xxx(fake_translation.gettext)
 
         # Turn back on our old translations
         translation.activate(self.native_lang)
@@ -49,10 +39,7 @@ class I18nTest (TestCase):
         # Restore the french translation function
         translation.activate("fr")
         fake_translation = translation.trans_real._active.value
-        if six.PY3:
-            fake_translation.gettext = self.original_gettext
-        else:
-            fake_translation.ugettext = self.original_ugettext
+        fake_translation.gettext = self.original_gettext
 
         # Turn back on our old translations
         translation.activate(self.native_lang)
